/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 65 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"

#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 69 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 72 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qeasingcurve.sip"
#include <qeasingcurve.h>
#line 75 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 164 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qrect.sip"
#include <qrect.h>
#line 78 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qlocale.sip"
#include <qlocale.h>
#line 81 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 84 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 87 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 98 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 90 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 99 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmargins.sip"
#include <qmargins.h>
#line 102 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 105 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 110 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 113 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 116 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 177 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 216 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qfont.sip"
#include <qfont.h>
#line 219 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 222 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 225 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 228 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 164 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 231 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 460 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 234 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 224 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 237 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 240 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 471 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 243 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 384 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 246 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 438 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 249 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 252 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 255 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 103 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 258 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 261 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 264 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpainter.sip"
#include <qpainter.h>
#line 267 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 1031 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 270 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 273 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 276 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qaction.sip"
#include <qaction.h>
#line 279 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 282 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicswidget.sip"
#include <qgraphicswidget.h>
#line 285 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 115 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmargins.sip"
#include <qmargins.h>
#line 288 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpalette.sip"
#include <qpalette.h>
#line 291 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 294 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicslayout.sip"
#include <qgraphicslayout.h>
#line 297 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 300 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 305 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 308 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 311 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 314 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 317 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 320 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 323 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 326 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 329 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 332 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 335 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 338 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 341 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 344 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 347 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicstransform.sip"
#include <qgraphicstransform.h>
#line 350 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 353 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 607 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 356 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qtransform.sip"
#include <qtransform.h>
#line 359 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qregion.sip"
#include <qregion.h>
#line 362 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 365 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 368 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 119 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 371 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 88 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 374 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 363 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 377 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 509 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 380 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 199 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 383 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 386 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 329 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 389 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 392 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcursor.sip"
#include <qcursor.h>
#line 395 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 398 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 578 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 401 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicsscene.sip"
#include <qgraphicsscene.h>
#line 404 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicslayoutitem.sip"
#include <qgraphicslayoutitem.h>
#line 407 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 410 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQChart.cpp"


class sipQtCharts_QChart : public ::QtCharts::QChart
{
public:
    sipQtCharts_QChart(::QGraphicsItem*, ::Qt::WindowFlags);
    virtual ~sipQtCharts_QChart();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void advance(int) SIP_OVERRIDE;
    ::QRectF boundingRect() const SIP_OVERRIDE;
    ::QPainterPath shape() const SIP_OVERRIDE;
    bool contains(const ::QPointF&) const SIP_OVERRIDE;
    bool collidesWithItem(const ::QGraphicsItem*, ::Qt::ItemSelectionMode) const SIP_OVERRIDE;
    bool collidesWithPath(const ::QPainterPath&, ::Qt::ItemSelectionMode) const SIP_OVERRIDE;
    bool isObscuredBy(const ::QGraphicsItem*) const SIP_OVERRIDE;
    ::QPainterPath opaqueArea() const SIP_OVERRIDE;
    void paint(::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*) SIP_OVERRIDE;
    int type() const SIP_OVERRIDE;
    void contextMenuEvent(::QGraphicsSceneContextMenuEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dropEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void hoverEnterEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void hoverMoveEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    ::QVariant itemChange(::QGraphicsItem::GraphicsItemChange, const ::QVariant&) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    bool sceneEvent(::QEvent*) SIP_OVERRIDE;
    bool sceneEventFilter(::QGraphicsItem*, ::QEvent*) SIP_OVERRIDE;
    void wheelEvent(::QGraphicsSceneWheelEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    ::QSizeF sizeHint(::Qt::SizeHint, const ::QSizeF&) const SIP_OVERRIDE;
    void updateGeometry() SIP_OVERRIDE;
    void getContentsMargins(::qreal*, ::qreal*, ::qreal*, ::qreal*) const SIP_OVERRIDE;
    void setGeometry(const ::QRectF&) SIP_OVERRIDE;
    void paintWindowFrame(::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*) SIP_OVERRIDE;
    void initStyleOption(::QStyleOption*) const SIP_OVERRIDE;
    bool windowFrameEvent(::QEvent*) SIP_OVERRIDE;
    ::Qt::WindowFrameSection windowFrameSectionAt(const ::QPointF&) const SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void moveEvent(::QGraphicsSceneMoveEvent*) SIP_OVERRIDE;
    void polishEvent() SIP_OVERRIDE;
    void resizeEvent(::QGraphicsSceneResizeEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void grabMouseEvent(::QEvent*) SIP_OVERRIDE;
    void ungrabMouseEvent(::QEvent*) SIP_OVERRIDE;
    void grabKeyboardEvent(::QEvent*) SIP_OVERRIDE;
    void ungrabKeyboardEvent(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtCharts_QChart(const sipQtCharts_QChart &);
    sipQtCharts_QChart &operator = (const sipQtCharts_QChart &);

    char sipPyMethods[59];
};

sipQtCharts_QChart::sipQtCharts_QChart(::QGraphicsItem*a0, ::Qt::WindowFlags a1): ::QtCharts::QChart(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QChart::~sipQtCharts_QChart()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtCharts_QChart::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtChart_qt_metaobject(sipPySelf, sipType_QtCharts_QChart);

    return ::QtCharts::QChart::metaObject();
}

int sipQtCharts_QChart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtCharts::QChart::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtChart_qt_metacall(sipPySelf, sipType_QtCharts_QChart, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtCharts_QChart::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtChart_qt_metacast(sipPySelf, sipType_QtCharts_QChart, _clname, &sipCpp) ? sipCpp : ::QtCharts::QChart::qt_metacast(_clname));
}

void sipQtCharts_QChart::advance(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_advance);

    if (!sipMeth)
    {
        ::QtCharts::QChart::advance(a0);
        return;
    }

    extern void sipVH_QtChart_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtChart_46(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QRectF sipQtCharts_QChart::boundingRect() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_boundingRect);

    if (!sipMeth)
        return ::QtCharts::QChart::boundingRect();

    extern ::QRectF sipVH_QtChart_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtChart_45(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QPainterPath sipQtCharts_QChart::shape() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_shape);

    if (!sipMeth)
        return ::QtCharts::QChart::shape();

    extern ::QPainterPath sipVH_QtChart_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtChart_40(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQtCharts_QChart::contains(const ::QPointF& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_contains);

    if (!sipMeth)
        return ::QtCharts::QChart::contains(a0);

    extern bool sipVH_QtChart_44(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPointF&);

    return sipVH_QtChart_44(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QChart::collidesWithItem(const ::QGraphicsItem*a0, ::Qt::ItemSelectionMode a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_collidesWithItem);

    if (!sipMeth)
        return ::QtCharts::QChart::collidesWithItem(a0, a1);

    extern bool sipVH_QtChart_43(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGraphicsItem*, ::Qt::ItemSelectionMode);

    return sipVH_QtChart_43(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQtCharts_QChart::collidesWithPath(const ::QPainterPath& a0, ::Qt::ItemSelectionMode a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_collidesWithPath);

    if (!sipMeth)
        return ::QtCharts::QChart::collidesWithPath(a0, a1);

    extern bool sipVH_QtChart_42(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPainterPath&, ::Qt::ItemSelectionMode);

    return sipVH_QtChart_42(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQtCharts_QChart::isObscuredBy(const ::QGraphicsItem*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isObscuredBy);

    if (!sipMeth)
        return ::QtCharts::QChart::isObscuredBy(a0);

    extern bool sipVH_QtChart_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGraphicsItem*);

    return sipVH_QtChart_41(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPainterPath sipQtCharts_QChart::opaqueArea() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_opaqueArea);

    if (!sipMeth)
        return ::QtCharts::QChart::opaqueArea();

    extern ::QPainterPath sipVH_QtChart_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtChart_40(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQtCharts_QChart::paint(::QPainter*a0, const ::QStyleOptionGraphicsItem*a1, ::QWidget*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_paint);

    if (!sipMeth)
    {
        ::QtCharts::QChart::paint(a0, a1, a2);
        return;
    }

    extern void sipVH_QtChart_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*);

    sipVH_QtChart_24(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

int sipQtCharts_QChart::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QtCharts::QChart::type();

    extern int sipVH_QtChart_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtChart_39(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQtCharts_QChart::contextMenuEvent(::QGraphicsSceneContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtChart_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneContextMenuEvent*);

    sipVH_QtChart_38(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::dragEnterEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtChart_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtChart_37(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::dragLeaveEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtChart_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtChart_37(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::dragMoveEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtChart_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtChart_37(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::dropEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::dropEvent(a0);
        return;
    }

    extern void sipVH_QtChart_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtChart_37(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtChart_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtChart_36(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtChart_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtChart_36(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::hoverEnterEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_hoverEnterEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::hoverEnterEvent(a0);
        return;
    }

    extern void sipVH_QtChart_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtChart_35(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::hoverLeaveEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_hoverLeaveEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::hoverLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtChart_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtChart_35(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::hoverMoveEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_hoverMoveEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::hoverMoveEvent(a0);
        return;
    }

    extern void sipVH_QtChart_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtChart_35(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtChart_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtChart_34(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQtCharts_QChart::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[21]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QtCharts::QChart::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtChart_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtChart_33(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQtCharts_QChart::itemChange(::QGraphicsItem::GraphicsItemChange a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_itemChange);

    if (!sipMeth)
        return ::QtCharts::QChart::itemChange(a0, a1);

    extern ::QVariant sipVH_QtChart_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsItem::GraphicsItemChange, const ::QVariant&);

    return sipVH_QtChart_32(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtCharts_QChart::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtChart_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtChart_31(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtChart_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtChart_31(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::mouseDoubleClickEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtChart_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtChart_30(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::mouseMoveEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtChart_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtChart_30(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::mousePressEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtChart_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtChart_30(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::mouseReleaseEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtChart_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtChart_30(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QChart::sceneEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_sceneEvent);

    if (!sipMeth)
        return ::QtCharts::QChart::sceneEvent(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QChart::sceneEventFilter(::QGraphicsItem*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_sceneEventFilter);

    if (!sipMeth)
        return ::QtCharts::QChart::sceneEventFilter(a0, a1);

    extern bool sipVH_QtChart_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsItem*, ::QEvent*);

    return sipVH_QtChart_29(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtCharts_QChart::wheelEvent(::QGraphicsSceneWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtChart_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneWheelEvent*);

    sipVH_QtChart_28(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QChart::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtCharts::QChart::event(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QChart::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtCharts::QChart::eventFilter(a0, a1);

    extern bool sipVH_QtChart_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtChart_4(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtCharts_QChart::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::timerEvent(a0);
        return;
    }

    extern void sipVH_QtChart_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtChart_3(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::childEvent(a0);
        return;
    }

    extern void sipVH_QtChart_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtChart_2(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::customEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QChart::connectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QChart::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSizeF sipQtCharts_QChart::sizeHint(::Qt::SizeHint a0, const ::QSizeF& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[39]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QtCharts::QChart::sizeHint(a0, a1);

    extern ::QSizeF sipVH_QtChart_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::SizeHint, const ::QSizeF&);

    return sipVH_QtChart_27(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtCharts_QChart::updateGeometry()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_updateGeometry);

    if (!sipMeth)
    {
        ::QtCharts::QChart::updateGeometry();
        return;
    }

    extern void sipVH_QtChart_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtChart_17(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQtCharts_QChart::getContentsMargins(::qreal*a0, ::qreal*a1, ::qreal*a2, ::qreal*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[41]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_getContentsMargins);

    if (!sipMeth)
    {
        ::QtCharts::QChart::getContentsMargins(a0, a1, a2, a3);
        return;
    }

    extern void sipVH_QtChart_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qreal*, ::qreal*, ::qreal*, ::qreal*);

    sipVH_QtChart_26(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipQtCharts_QChart::setGeometry(const ::QRectF& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_setGeometry);

    if (!sipMeth)
    {
        ::QtCharts::QChart::setGeometry(a0);
        return;
    }

    extern void sipVH_QtChart_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QRectF&);

    sipVH_QtChart_25(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::paintWindowFrame(::QPainter*a0, const ::QStyleOptionGraphicsItem*a1, ::QWidget*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_paintWindowFrame);

    if (!sipMeth)
    {
        ::QtCharts::QChart::paintWindowFrame(a0, a1, a2);
        return;
    }

    extern void sipVH_QtChart_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*);

    sipVH_QtChart_24(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQtCharts_QChart::initStyleOption(::QStyleOption*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[44]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initStyleOption);

    if (!sipMeth)
    {
        ::QtCharts::QChart::initStyleOption(a0);
        return;
    }

    extern void sipVH_QtChart_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyleOption*);

    sipVH_QtChart_23(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QChart::windowFrameEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_windowFrameEvent);

    if (!sipMeth)
        return ::QtCharts::QChart::windowFrameEvent(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::Qt::WindowFrameSection sipQtCharts_QChart::windowFrameSectionAt(const ::QPointF& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_windowFrameSectionAt);

    if (!sipMeth)
        return ::QtCharts::QChart::windowFrameSectionAt(a0);

    extern ::Qt::WindowFrameSection sipVH_QtChart_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPointF&);

    return sipVH_QtChart_22(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[47], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::changeEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[48], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::closeEvent(a0);
        return;
    }

    extern void sipVH_QtChart_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtChart_21(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QChart::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[49], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QtCharts::QChart::focusNextPrevChild(a0);

    extern bool sipVH_QtChart_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtChart_20(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[50], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::hideEvent(a0);
        return;
    }

    extern void sipVH_QtChart_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtChart_19(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::moveEvent(::QGraphicsSceneMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[51], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::moveEvent(a0);
        return;
    }

    extern void sipVH_QtChart_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMoveEvent*);

    sipVH_QtChart_18(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::polishEvent()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[52], &sipPySelf, SIP_NULLPTR, sipName_polishEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::polishEvent();
        return;
    }

    extern void sipVH_QtChart_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtChart_17(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQtCharts_QChart::resizeEvent(::QGraphicsSceneResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[53], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtChart_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneResizeEvent*);

    sipVH_QtChart_16(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[54], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::showEvent(a0);
        return;
    }

    extern void sipVH_QtChart_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtChart_15(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::grabMouseEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[55], &sipPySelf, SIP_NULLPTR, sipName_grabMouseEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::grabMouseEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::ungrabMouseEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[56], &sipPySelf, SIP_NULLPTR, sipName_ungrabMouseEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::ungrabMouseEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::grabKeyboardEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[57], &sipPySelf, SIP_NULLPTR, sipName_grabKeyboardEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::grabKeyboardEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QChart::ungrabKeyboardEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[58], &sipPySelf, SIP_NULLPTR, sipName_ungrabKeyboardEvent);

    if (!sipMeth)
    {
        ::QtCharts::QChart::ungrabKeyboardEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtCharts_QChart_addSeries, "addSeries(self, series: QAbstractSeries|None)");

extern "C" {static PyObject *meth_QtCharts_QChart_addSeries(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_addSeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractSeries* a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QtCharts_QAbstractSeries, &a0))
        {
            sipCpp->addSeries(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_addSeries, doc_QtCharts_QChart_addSeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_removeSeries, "removeSeries(self, series: QAbstractSeries|None)");

extern "C" {static PyObject *meth_QtCharts_QChart_removeSeries(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_removeSeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractSeries* a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ<", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QtCharts_QAbstractSeries, &a0))
        {
            sipCpp->removeSeries(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_removeSeries, doc_QtCharts_QChart_removeSeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_removeAllSeries, "removeAllSeries(self)");

extern "C" {static PyObject *meth_QtCharts_QChart_removeAllSeries(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_removeAllSeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            sipCpp->removeAllSeries();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_removeAllSeries, doc_QtCharts_QChart_removeAllSeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_series, "series(self) -> list[QAbstractSeries]");

extern "C" {static PyObject *meth_QtCharts_QChart_series(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_series(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            QList< ::QtCharts::QAbstractSeries*>*sipRes;

            sipRes = new QList< ::QtCharts::QAbstractSeries*>(sipCpp->series());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QtCharts_QAbstractSeries, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_series, doc_QtCharts_QChart_series);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setTheme, "setTheme(self, theme: QChart.ChartTheme)");

extern "C" {static PyObject *meth_QtCharts_QChart_setTheme(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setTheme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QChart::ChartTheme a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QtCharts_QChart_ChartTheme, &a0))
        {
            sipCpp->setTheme(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setTheme, doc_QtCharts_QChart_setTheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_theme, "theme(self) -> QChart.ChartTheme");

extern "C" {static PyObject *meth_QtCharts_QChart_theme(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_theme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QtCharts::QChart::ChartTheme sipRes;

            sipRes = sipCpp->theme();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QChart_ChartTheme);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_theme, doc_QtCharts_QChart_theme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setTitle, "setTitle(self, title: str|None)");

extern "C" {static PyObject *meth_QtCharts_QChart_setTitle(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setTitle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTitle(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setTitle, doc_QtCharts_QChart_setTitle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_title, "title(self) -> str");

extern "C" {static PyObject *meth_QtCharts_QChart_title(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_title(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->title());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_title, doc_QtCharts_QChart_title);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setTitleFont, "setTitleFont(self, font: QFont)");

extern "C" {static PyObject *meth_QtCharts_QChart_setTitleFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setTitleFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFont* a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setTitleFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setTitleFont, doc_QtCharts_QChart_setTitleFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_titleFont, "titleFont(self) -> QFont");

extern "C" {static PyObject *meth_QtCharts_QChart_titleFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_titleFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->titleFont());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_titleFont, doc_QtCharts_QChart_titleFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setTitleBrush, "setTitleBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QChart_setTitleBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setTitleBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setTitleBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setTitleBrush, doc_QtCharts_QChart_setTitleBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_titleBrush, "titleBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QChart_titleBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_titleBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->titleBrush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_titleBrush, doc_QtCharts_QChart_titleBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setBackgroundBrush, "setBackgroundBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QChart_setBackgroundBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setBackgroundBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBackgroundBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setBackgroundBrush, doc_QtCharts_QChart_setBackgroundBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_backgroundBrush, "backgroundBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QChart_backgroundBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_backgroundBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->backgroundBrush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_backgroundBrush, doc_QtCharts_QChart_backgroundBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setBackgroundPen, "setBackgroundPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QChart_setBackgroundPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setBackgroundPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setBackgroundPen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setBackgroundPen, doc_QtCharts_QChart_setBackgroundPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_backgroundPen, "backgroundPen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QChart_backgroundPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_backgroundPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->backgroundPen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_backgroundPen, doc_QtCharts_QChart_backgroundPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setBackgroundVisible, "setBackgroundVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QChart_setBackgroundVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setBackgroundVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QChart *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QChart, &sipCpp, &a0))
        {
            sipCpp->setBackgroundVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setBackgroundVisible, doc_QtCharts_QChart_setBackgroundVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_isBackgroundVisible, "isBackgroundVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QChart_isBackgroundVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_isBackgroundVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isBackgroundVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_isBackgroundVisible, doc_QtCharts_QChart_isBackgroundVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setAnimationOptions, "setAnimationOptions(self, options: QChart.AnimationOptions|QChart.AnimationOption)");

extern "C" {static PyObject *meth_QtCharts_QChart_setAnimationOptions(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setAnimationOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QChart::AnimationOptions* a0;
        int a0State = 0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QtCharts_QChart_AnimationOptions, &a0, &a0State))
        {
            sipCpp->setAnimationOptions(*a0);
            sipReleaseType(a0, sipType_QtCharts_QChart_AnimationOptions, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setAnimationOptions, doc_QtCharts_QChart_setAnimationOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_animationOptions, "animationOptions(self) -> QChart.AnimationOptions");

extern "C" {static PyObject *meth_QtCharts_QChart_animationOptions(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_animationOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QtCharts::QChart::AnimationOptions*sipRes;

            sipRes = new ::QtCharts::QChart::AnimationOptions(sipCpp->animationOptions());

            return sipConvertFromNewType(sipRes, sipType_QtCharts_QChart_AnimationOptions, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_animationOptions, doc_QtCharts_QChart_animationOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_zoomIn, "zoomIn(self)\n"
"zoomIn(self, rect: QRectF)");

extern "C" {static PyObject *meth_QtCharts_QChart_zoomIn(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_zoomIn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            sipCpp->zoomIn();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QRectF* a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QRectF, &a0))
        {
            sipCpp->zoomIn(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_zoomIn, doc_QtCharts_QChart_zoomIn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_zoomOut, "zoomOut(self)");

extern "C" {static PyObject *meth_QtCharts_QChart_zoomOut(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_zoomOut(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            sipCpp->zoomOut();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_zoomOut, doc_QtCharts_QChart_zoomOut);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_zoom, "zoom(self, factor: float)");

extern "C" {static PyObject *meth_QtCharts_QChart_zoom(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_zoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QChart, &sipCpp, &a0))
        {
            sipCpp->zoom(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_zoom, doc_QtCharts_QChart_zoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_legend, "legend(self) -> QLegend|None");

extern "C" {static PyObject *meth_QtCharts_QChart_legend(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_legend(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QtCharts::QLegend*sipRes;

            sipRes = sipCpp->legend();

            return sipConvertFromType(sipRes, sipType_QtCharts_QLegend, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_legend, doc_QtCharts_QChart_legend);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setAxisX, "setAxisX(self, axis: QAbstractAxis|None, series: QAbstractSeries|None = None)");

extern "C" {static PyObject *meth_QtCharts_QChart_setAxisX(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setAxisX(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractAxis* a0;
        ::QtCharts::QAbstractSeries* a1 = 0;
        ::QtCharts::QChart *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_series,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ:|J:", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QtCharts_QAbstractAxis, &a0, sipType_QtCharts_QAbstractSeries, &a1))
        {
            sipCpp->setAxisX(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setAxisX, doc_QtCharts_QChart_setAxisX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setAxisY, "setAxisY(self, axis: QAbstractAxis|None, series: QAbstractSeries|None = None)");

extern "C" {static PyObject *meth_QtCharts_QChart_setAxisY(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setAxisY(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractAxis* a0;
        ::QtCharts::QAbstractSeries* a1 = 0;
        ::QtCharts::QChart *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_series,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ:|J:", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QtCharts_QAbstractAxis, &a0, sipType_QtCharts_QAbstractSeries, &a1))
        {
            sipCpp->setAxisY(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setAxisY, doc_QtCharts_QChart_setAxisY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_axisX, "axisX(self, series: QAbstractSeries|None = None) -> QAbstractAxis|None");

extern "C" {static PyObject *meth_QtCharts_QChart_axisX(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_axisX(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractSeries* a0 = 0;
        const ::QtCharts::QChart *sipCpp;

        static const char *sipKwdList[] = {
            sipName_series,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J8", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QtCharts_QAbstractSeries, &a0))
        {
            ::QtCharts::QAbstractAxis*sipRes;

            sipRes = sipCpp->axisX(a0);

            return sipConvertFromType(sipRes, sipType_QtCharts_QAbstractAxis, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_axisX, doc_QtCharts_QChart_axisX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_axisY, "axisY(self, series: QAbstractSeries|None = None) -> QAbstractAxis|None");

extern "C" {static PyObject *meth_QtCharts_QChart_axisY(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_axisY(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractSeries* a0 = 0;
        const ::QtCharts::QChart *sipCpp;

        static const char *sipKwdList[] = {
            sipName_series,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J8", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QtCharts_QAbstractSeries, &a0))
        {
            ::QtCharts::QAbstractAxis*sipRes;

            sipRes = sipCpp->axisY(a0);

            return sipConvertFromType(sipRes, sipType_QtCharts_QAbstractAxis, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_axisY, doc_QtCharts_QChart_axisY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_createDefaultAxes, "createDefaultAxes(self)");

extern "C" {static PyObject *meth_QtCharts_QChart_createDefaultAxes(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_createDefaultAxes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            sipCpp->createDefaultAxes();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_createDefaultAxes, doc_QtCharts_QChart_createDefaultAxes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setDropShadowEnabled, "setDropShadowEnabled(self, enabled: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QChart_setDropShadowEnabled(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setDropShadowEnabled(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QChart *sipCpp;

        static const char *sipKwdList[] = {
            sipName_enabled,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QChart, &sipCpp, &a0))
        {
            sipCpp->setDropShadowEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setDropShadowEnabled, doc_QtCharts_QChart_setDropShadowEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_isDropShadowEnabled, "isDropShadowEnabled(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QChart_isDropShadowEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_isDropShadowEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDropShadowEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_isDropShadowEnabled, doc_QtCharts_QChart_isDropShadowEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_scroll, "scroll(self, dx: float, dy: float)");

extern "C" {static PyObject *meth_QtCharts_QChart_scroll(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_scroll(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::qreal a1;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QtCharts_QChart, &sipCpp, &a0, &a1))
        {
            sipCpp->scroll(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_scroll, doc_QtCharts_QChart_scroll);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_plotArea, "plotArea(self) -> QRectF");

extern "C" {static PyObject *meth_QtCharts_QChart_plotArea(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_plotArea(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF(sipCpp->plotArea());

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_plotArea, doc_QtCharts_QChart_plotArea);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_addAxis, "addAxis(self, axis: QAbstractAxis|None, alignment: Qt.Alignment|Qt.AlignmentFlag)");

extern "C" {static PyObject *meth_QtCharts_QChart_addAxis(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_addAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractAxis* a0;
        ::Qt::Alignment* a1;
        int a1State = 0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:J1", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QtCharts_QAbstractAxis, &a0, sipType_Qt_Alignment, &a1, &a1State))
        {
            sipCpp->addAxis(a0, *a1);
            sipReleaseType(a1, sipType_Qt_Alignment, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_addAxis, doc_QtCharts_QChart_addAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_removeAxis, "removeAxis(self, axis: QAbstractAxis|None)");

extern "C" {static PyObject *meth_QtCharts_QChart_removeAxis(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_removeAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractAxis* a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ<", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QtCharts_QAbstractAxis, &a0))
        {
            sipCpp->removeAxis(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_removeAxis, doc_QtCharts_QChart_removeAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_axes, "axes(self, orientation: Qt.Orientations|Qt.Orientation = Qt.Orientation.Horizontal|Qt.Orientation.Vertical, series: QAbstractSeries|None = None) -> list[QAbstractAxis]");

extern "C" {static PyObject *meth_QtCharts_QChart_axes(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_axes(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Orientations a0def = Qt::Orientation::Horizontal|Qt::Orientation::Vertical;
        ::Qt::Orientations* a0 = &a0def;
        int a0State = 0;
        ::QtCharts::QAbstractSeries* a1 = 0;
        const ::QtCharts::QChart *sipCpp;

        static const char *sipKwdList[] = {
            sipName_orientation,
            sipName_series,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1J8", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_Qt_Orientations, &a0, &a0State, sipType_QtCharts_QAbstractSeries, &a1))
        {
            QList< ::QtCharts::QAbstractAxis*>*sipRes;

            sipRes = new QList< ::QtCharts::QAbstractAxis*>(sipCpp->axes(*a0, a1));
            sipReleaseType(a0, sipType_Qt_Orientations, a0State);

            return sipConvertFromNewType(sipRes, sipType_QList_0101QtCharts_QAbstractAxis, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_axes, doc_QtCharts_QChart_axes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setMargins, "setMargins(self, margins: QMargins)");

extern "C" {static PyObject *meth_QtCharts_QChart_setMargins(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setMargins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMargins* a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QMargins, &a0))
        {
            sipCpp->setMargins(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setMargins, doc_QtCharts_QChart_setMargins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_margins, "margins(self) -> QMargins");

extern "C" {static PyObject *meth_QtCharts_QChart_margins(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_margins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QMargins*sipRes;

            sipRes = new ::QMargins(sipCpp->margins());

            return sipConvertFromNewType(sipRes, sipType_QMargins, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_margins, doc_QtCharts_QChart_margins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_mapToValue, "mapToValue(self, position: QPointF|QPoint, series: QAbstractSeries|None = None) -> QPointF");

extern "C" {static PyObject *meth_QtCharts_QChart_mapToValue(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_mapToValue(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        int a0State = 0;
        ::QtCharts::QAbstractSeries* a1 = 0;
        ::QtCharts::QChart *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_series,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J8", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QPointF, &a0, &a0State, sipType_QtCharts_QAbstractSeries, &a1))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->mapToValue(*a0, a1));
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_mapToValue, doc_QtCharts_QChart_mapToValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_mapToPosition, "mapToPosition(self, value: QPointF|QPoint, series: QAbstractSeries|None = None) -> QPointF");

extern "C" {static PyObject *meth_QtCharts_QChart_mapToPosition(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_mapToPosition(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        int a0State = 0;
        ::QtCharts::QAbstractSeries* a1 = 0;
        ::QtCharts::QChart *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_series,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J8", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QPointF, &a0, &a0State, sipType_QtCharts_QAbstractSeries, &a1))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->mapToPosition(*a0, a1));
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_mapToPosition, doc_QtCharts_QChart_mapToPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setBackgroundRoundness, "setBackgroundRoundness(self, diameter: float)");

extern "C" {static PyObject *meth_QtCharts_QChart_setBackgroundRoundness(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setBackgroundRoundness(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QChart, &sipCpp, &a0))
        {
            sipCpp->setBackgroundRoundness(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setBackgroundRoundness, doc_QtCharts_QChart_setBackgroundRoundness);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_backgroundRoundness, "backgroundRoundness(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QChart_backgroundRoundness(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_backgroundRoundness(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->backgroundRoundness();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_backgroundRoundness, doc_QtCharts_QChart_backgroundRoundness);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_zoomReset, "zoomReset(self)");

extern "C" {static PyObject *meth_QtCharts_QChart_zoomReset(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_zoomReset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            sipCpp->zoomReset();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_zoomReset, doc_QtCharts_QChart_zoomReset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_isZoomed, "isZoomed(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QChart_isZoomed(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_isZoomed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isZoomed();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_isZoomed, doc_QtCharts_QChart_isZoomed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setPlotArea, "setPlotArea(self, rect: QRectF)");

extern "C" {static PyObject *meth_QtCharts_QChart_setPlotArea(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setPlotArea(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRectF* a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QRectF, &a0))
        {
            sipCpp->setPlotArea(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setPlotArea, doc_QtCharts_QChart_setPlotArea);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setPlotAreaBackgroundBrush, "setPlotAreaBackgroundBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QChart_setPlotAreaBackgroundBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setPlotAreaBackgroundBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setPlotAreaBackgroundBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setPlotAreaBackgroundBrush, doc_QtCharts_QChart_setPlotAreaBackgroundBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_plotAreaBackgroundBrush, "plotAreaBackgroundBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QChart_plotAreaBackgroundBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_plotAreaBackgroundBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->plotAreaBackgroundBrush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_plotAreaBackgroundBrush, doc_QtCharts_QChart_plotAreaBackgroundBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setPlotAreaBackgroundPen, "setPlotAreaBackgroundPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QChart_setPlotAreaBackgroundPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setPlotAreaBackgroundPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setPlotAreaBackgroundPen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setPlotAreaBackgroundPen, doc_QtCharts_QChart_setPlotAreaBackgroundPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_plotAreaBackgroundPen, "plotAreaBackgroundPen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QChart_plotAreaBackgroundPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_plotAreaBackgroundPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->plotAreaBackgroundPen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_plotAreaBackgroundPen, doc_QtCharts_QChart_plotAreaBackgroundPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setPlotAreaBackgroundVisible, "setPlotAreaBackgroundVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QChart_setPlotAreaBackgroundVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setPlotAreaBackgroundVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QChart *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QChart, &sipCpp, &a0))
        {
            sipCpp->setPlotAreaBackgroundVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setPlotAreaBackgroundVisible, doc_QtCharts_QChart_setPlotAreaBackgroundVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_isPlotAreaBackgroundVisible, "isPlotAreaBackgroundVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QChart_isPlotAreaBackgroundVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_isPlotAreaBackgroundVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isPlotAreaBackgroundVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_isPlotAreaBackgroundVisible, doc_QtCharts_QChart_isPlotAreaBackgroundVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_chartType, "chartType(self) -> QChart.ChartType");

extern "C" {static PyObject *meth_QtCharts_QChart_chartType(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_chartType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QtCharts::QChart::ChartType sipRes;

            sipRes = sipCpp->chartType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QChart_ChartType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_chartType, doc_QtCharts_QChart_chartType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setLocalizeNumbers, "setLocalizeNumbers(self, localize: bool)");

extern "C" {static PyObject *meth_QtCharts_QChart_setLocalizeNumbers(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setLocalizeNumbers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtCharts_QChart, &sipCpp, &a0))
        {
            sipCpp->setLocalizeNumbers(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setLocalizeNumbers, doc_QtCharts_QChart_setLocalizeNumbers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_localizeNumbers, "localizeNumbers(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QChart_localizeNumbers(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_localizeNumbers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->localizeNumbers();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_localizeNumbers, doc_QtCharts_QChart_localizeNumbers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setLocale, "setLocale(self, locale: QLocale)");

extern "C" {static PyObject *meth_QtCharts_QChart_setLocale(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setLocale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QLocale, &a0))
        {
            sipCpp->setLocale(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setLocale, doc_QtCharts_QChart_setLocale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_locale, "locale(self) -> QLocale");

extern "C" {static PyObject *meth_QtCharts_QChart_locale(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_locale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(sipCpp->locale());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_locale, doc_QtCharts_QChart_locale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setAnimationDuration, "setAnimationDuration(self, msecs: int)");

extern "C" {static PyObject *meth_QtCharts_QChart_setAnimationDuration(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setAnimationDuration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QChart, &sipCpp, &a0))
        {
            sipCpp->setAnimationDuration(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setAnimationDuration, doc_QtCharts_QChart_setAnimationDuration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_animationDuration, "animationDuration(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QChart_animationDuration(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_animationDuration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->animationDuration();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_animationDuration, doc_QtCharts_QChart_animationDuration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_setAnimationEasingCurve, "setAnimationEasingCurve(self, curve: QEasingCurve|QEasingCurve.Type)");

extern "C" {static PyObject *meth_QtCharts_QChart_setAnimationEasingCurve(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_setAnimationEasingCurve(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEasingCurve* a0;
        int a0State = 0;
        ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QChart, &sipCpp, sipType_QEasingCurve, &a0, &a0State))
        {
            sipCpp->setAnimationEasingCurve(*a0);
            sipReleaseType(const_cast< ::QEasingCurve *>(a0), sipType_QEasingCurve, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_setAnimationEasingCurve, doc_QtCharts_QChart_setAnimationEasingCurve);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QChart_animationEasingCurve, "animationEasingCurve(self) -> QEasingCurve");

extern "C" {static PyObject *meth_QtCharts_QChart_animationEasingCurve(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QChart_animationEasingCurve(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QChart *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QChart, &sipCpp))
        {
            ::QEasingCurve*sipRes;

            sipRes = new ::QEasingCurve(sipCpp->animationEasingCurve());

            return sipConvertFromNewType(sipRes, sipType_QEasingCurve, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QChart, sipName_animationEasingCurve, doc_QtCharts_QChart_animationEasingCurve);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QChart(void *, const sipTypeDef *);}
static void *cast_QtCharts_QChart(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QChart *sipCpp = reinterpret_cast< ::QtCharts::QChart *>(sipCppV);

    if (targetType == sipType_QtCharts_QChart)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGraphicsWidget)->ctd_cast(static_cast< ::QGraphicsWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QChart(void *, int);}
static void release_QtCharts_QChart(void *sipCppV, int)
{
    ::QtCharts::QChart *sipCpp = reinterpret_cast< ::QtCharts::QChart *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtCharts_QChart(Py_ssize_t);}
static void *array_QtCharts_QChart(Py_ssize_t sipNrElem)
{
    return new ::QtCharts::QChart[sipNrElem];
}


extern "C" {static void array_delete_QtCharts_QChart(void *);}
static void array_delete_QtCharts_QChart(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtCharts::QChart *>(sipCpp);
}


extern "C" {static void dealloc_QtCharts_QChart(sipSimpleWrapper *);}
static void dealloc_QtCharts_QChart(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtCharts_QChart *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QChart(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtCharts_QChart(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtCharts_QChart(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtCharts_QChart *sipCpp = SIP_NULLPTR;

    {
        ::QGraphicsItem* a0 = 0;
        ::Qt::WindowFlags a1def = Qt::WindowFlags();
        ::Qt::WindowFlags* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
            sipName_flags,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JHJ1", sipType_QGraphicsItem, &a0, sipOwner, sipType_Qt_WindowFlags, &a1, &a1State))
        {
            sipCpp = new sipQtCharts_QChart(a0, *a1);
            sipReleaseType(a1, sipType_Qt_WindowFlags, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QChart[] = {{14, 2, 1}};


static PyMethodDef methods_QtCharts_QChart[] = {
    {sipName_addAxis, meth_QtCharts_QChart_addAxis, METH_VARARGS, doc_QtCharts_QChart_addAxis},
    {sipName_addSeries, meth_QtCharts_QChart_addSeries, METH_VARARGS, doc_QtCharts_QChart_addSeries},
    {sipName_animationDuration, meth_QtCharts_QChart_animationDuration, METH_VARARGS, doc_QtCharts_QChart_animationDuration},
    {sipName_animationEasingCurve, meth_QtCharts_QChart_animationEasingCurve, METH_VARARGS, doc_QtCharts_QChart_animationEasingCurve},
    {sipName_animationOptions, meth_QtCharts_QChart_animationOptions, METH_VARARGS, doc_QtCharts_QChart_animationOptions},
    {sipName_axes, SIP_MLMETH_CAST(meth_QtCharts_QChart_axes), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QChart_axes},
    {sipName_axisX, SIP_MLMETH_CAST(meth_QtCharts_QChart_axisX), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QChart_axisX},
    {sipName_axisY, SIP_MLMETH_CAST(meth_QtCharts_QChart_axisY), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QChart_axisY},
    {sipName_backgroundBrush, meth_QtCharts_QChart_backgroundBrush, METH_VARARGS, doc_QtCharts_QChart_backgroundBrush},
    {sipName_backgroundPen, meth_QtCharts_QChart_backgroundPen, METH_VARARGS, doc_QtCharts_QChart_backgroundPen},
    {sipName_backgroundRoundness, meth_QtCharts_QChart_backgroundRoundness, METH_VARARGS, doc_QtCharts_QChart_backgroundRoundness},
    {sipName_chartType, meth_QtCharts_QChart_chartType, METH_VARARGS, doc_QtCharts_QChart_chartType},
    {sipName_createDefaultAxes, meth_QtCharts_QChart_createDefaultAxes, METH_VARARGS, doc_QtCharts_QChart_createDefaultAxes},
    {sipName_isBackgroundVisible, meth_QtCharts_QChart_isBackgroundVisible, METH_VARARGS, doc_QtCharts_QChart_isBackgroundVisible},
    {sipName_isDropShadowEnabled, meth_QtCharts_QChart_isDropShadowEnabled, METH_VARARGS, doc_QtCharts_QChart_isDropShadowEnabled},
    {sipName_isPlotAreaBackgroundVisible, meth_QtCharts_QChart_isPlotAreaBackgroundVisible, METH_VARARGS, doc_QtCharts_QChart_isPlotAreaBackgroundVisible},
    {sipName_isZoomed, meth_QtCharts_QChart_isZoomed, METH_VARARGS, doc_QtCharts_QChart_isZoomed},
    {sipName_legend, meth_QtCharts_QChart_legend, METH_VARARGS, doc_QtCharts_QChart_legend},
    {sipName_locale, meth_QtCharts_QChart_locale, METH_VARARGS, doc_QtCharts_QChart_locale},
    {sipName_localizeNumbers, meth_QtCharts_QChart_localizeNumbers, METH_VARARGS, doc_QtCharts_QChart_localizeNumbers},
    {sipName_mapToPosition, SIP_MLMETH_CAST(meth_QtCharts_QChart_mapToPosition), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QChart_mapToPosition},
    {sipName_mapToValue, SIP_MLMETH_CAST(meth_QtCharts_QChart_mapToValue), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QChart_mapToValue},
    {sipName_margins, meth_QtCharts_QChart_margins, METH_VARARGS, doc_QtCharts_QChart_margins},
    {sipName_plotArea, meth_QtCharts_QChart_plotArea, METH_VARARGS, doc_QtCharts_QChart_plotArea},
    {sipName_plotAreaBackgroundBrush, meth_QtCharts_QChart_plotAreaBackgroundBrush, METH_VARARGS, doc_QtCharts_QChart_plotAreaBackgroundBrush},
    {sipName_plotAreaBackgroundPen, meth_QtCharts_QChart_plotAreaBackgroundPen, METH_VARARGS, doc_QtCharts_QChart_plotAreaBackgroundPen},
    {sipName_removeAllSeries, meth_QtCharts_QChart_removeAllSeries, METH_VARARGS, doc_QtCharts_QChart_removeAllSeries},
    {sipName_removeAxis, meth_QtCharts_QChart_removeAxis, METH_VARARGS, doc_QtCharts_QChart_removeAxis},
    {sipName_removeSeries, meth_QtCharts_QChart_removeSeries, METH_VARARGS, doc_QtCharts_QChart_removeSeries},
    {sipName_scroll, meth_QtCharts_QChart_scroll, METH_VARARGS, doc_QtCharts_QChart_scroll},
    {sipName_series, meth_QtCharts_QChart_series, METH_VARARGS, doc_QtCharts_QChart_series},
    {sipName_setAnimationDuration, meth_QtCharts_QChart_setAnimationDuration, METH_VARARGS, doc_QtCharts_QChart_setAnimationDuration},
    {sipName_setAnimationEasingCurve, meth_QtCharts_QChart_setAnimationEasingCurve, METH_VARARGS, doc_QtCharts_QChart_setAnimationEasingCurve},
    {sipName_setAnimationOptions, meth_QtCharts_QChart_setAnimationOptions, METH_VARARGS, doc_QtCharts_QChart_setAnimationOptions},
    {sipName_setAxisX, SIP_MLMETH_CAST(meth_QtCharts_QChart_setAxisX), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QChart_setAxisX},
    {sipName_setAxisY, SIP_MLMETH_CAST(meth_QtCharts_QChart_setAxisY), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QChart_setAxisY},
    {sipName_setBackgroundBrush, meth_QtCharts_QChart_setBackgroundBrush, METH_VARARGS, doc_QtCharts_QChart_setBackgroundBrush},
    {sipName_setBackgroundPen, meth_QtCharts_QChart_setBackgroundPen, METH_VARARGS, doc_QtCharts_QChart_setBackgroundPen},
    {sipName_setBackgroundRoundness, meth_QtCharts_QChart_setBackgroundRoundness, METH_VARARGS, doc_QtCharts_QChart_setBackgroundRoundness},
    {sipName_setBackgroundVisible, SIP_MLMETH_CAST(meth_QtCharts_QChart_setBackgroundVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QChart_setBackgroundVisible},
    {sipName_setDropShadowEnabled, SIP_MLMETH_CAST(meth_QtCharts_QChart_setDropShadowEnabled), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QChart_setDropShadowEnabled},
    {sipName_setLocale, meth_QtCharts_QChart_setLocale, METH_VARARGS, doc_QtCharts_QChart_setLocale},
    {sipName_setLocalizeNumbers, meth_QtCharts_QChart_setLocalizeNumbers, METH_VARARGS, doc_QtCharts_QChart_setLocalizeNumbers},
    {sipName_setMargins, meth_QtCharts_QChart_setMargins, METH_VARARGS, doc_QtCharts_QChart_setMargins},
    {sipName_setPlotArea, meth_QtCharts_QChart_setPlotArea, METH_VARARGS, doc_QtCharts_QChart_setPlotArea},
    {sipName_setPlotAreaBackgroundBrush, meth_QtCharts_QChart_setPlotAreaBackgroundBrush, METH_VARARGS, doc_QtCharts_QChart_setPlotAreaBackgroundBrush},
    {sipName_setPlotAreaBackgroundPen, meth_QtCharts_QChart_setPlotAreaBackgroundPen, METH_VARARGS, doc_QtCharts_QChart_setPlotAreaBackgroundPen},
    {sipName_setPlotAreaBackgroundVisible, SIP_MLMETH_CAST(meth_QtCharts_QChart_setPlotAreaBackgroundVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QChart_setPlotAreaBackgroundVisible},
    {sipName_setTheme, meth_QtCharts_QChart_setTheme, METH_VARARGS, doc_QtCharts_QChart_setTheme},
    {sipName_setTitle, meth_QtCharts_QChart_setTitle, METH_VARARGS, doc_QtCharts_QChart_setTitle},
    {sipName_setTitleBrush, meth_QtCharts_QChart_setTitleBrush, METH_VARARGS, doc_QtCharts_QChart_setTitleBrush},
    {sipName_setTitleFont, meth_QtCharts_QChart_setTitleFont, METH_VARARGS, doc_QtCharts_QChart_setTitleFont},
    {sipName_theme, meth_QtCharts_QChart_theme, METH_VARARGS, doc_QtCharts_QChart_theme},
    {sipName_title, meth_QtCharts_QChart_title, METH_VARARGS, doc_QtCharts_QChart_title},
    {sipName_titleBrush, meth_QtCharts_QChart_titleBrush, METH_VARARGS, doc_QtCharts_QChart_titleBrush},
    {sipName_titleFont, meth_QtCharts_QChart_titleFont, METH_VARARGS, doc_QtCharts_QChart_titleFont},
    {sipName_zoom, meth_QtCharts_QChart_zoom, METH_VARARGS, doc_QtCharts_QChart_zoom},
    {sipName_zoomIn, meth_QtCharts_QChart_zoomIn, METH_VARARGS, doc_QtCharts_QChart_zoomIn},
    {sipName_zoomOut, meth_QtCharts_QChart_zoomOut, METH_VARARGS, doc_QtCharts_QChart_zoomOut},
    {sipName_zoomReset, meth_QtCharts_QChart_zoomReset, METH_VARARGS, doc_QtCharts_QChart_zoomReset}
};

static sipEnumMemberDef enummembers_QtCharts_QChart[] = {
    {sipName_AllAnimations, static_cast<int>(::QtCharts::QChart::AllAnimations), 32},
    {sipName_ChartThemeBlueCerulean, static_cast<int>(::QtCharts::QChart::ChartThemeBlueCerulean), 34},
    {sipName_ChartThemeBlueIcy, static_cast<int>(::QtCharts::QChart::ChartThemeBlueIcy), 34},
    {sipName_ChartThemeBlueNcs, static_cast<int>(::QtCharts::QChart::ChartThemeBlueNcs), 34},
    {sipName_ChartThemeBrownSand, static_cast<int>(::QtCharts::QChart::ChartThemeBrownSand), 34},
    {sipName_ChartThemeDark, static_cast<int>(::QtCharts::QChart::ChartThemeDark), 34},
    {sipName_ChartThemeHighContrast, static_cast<int>(::QtCharts::QChart::ChartThemeHighContrast), 34},
    {sipName_ChartThemeLight, static_cast<int>(::QtCharts::QChart::ChartThemeLight), 34},
    {sipName_ChartThemeQt, static_cast<int>(::QtCharts::QChart::ChartThemeQt), 34},
    {sipName_ChartTypeCartesian, static_cast<int>(::QtCharts::QChart::ChartTypeCartesian), 35},
    {sipName_ChartTypePolar, static_cast<int>(::QtCharts::QChart::ChartTypePolar), 35},
    {sipName_ChartTypeUndefined, static_cast<int>(::QtCharts::QChart::ChartTypeUndefined), 35},
    {sipName_GridAxisAnimations, static_cast<int>(::QtCharts::QChart::GridAxisAnimations), 32},
    {sipName_NoAnimation, static_cast<int>(::QtCharts::QChart::NoAnimation), 32},
    {sipName_SeriesAnimations, static_cast<int>(::QtCharts::QChart::SeriesAnimations), 32},
};

PyDoc_STRVAR(doc_QtCharts_QChart, "\1QChart(parent: QGraphicsItem|None = None, flags: Qt.WindowFlags|Qt.WindowType = Qt.WindowFlags())");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QChart[] = {
    {"plotAreaChanged(QRectF)", "\1plotAreaChanged(self, plotArea: QRectF)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QChart = {
    &::QtCharts::QChart::staticMetaObject,
    0,
    signals_QtCharts_QChart,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QChart = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QChart,
        SIP_NULLPTR,
        &plugin_QtCharts_QChart,
    },
    {
        sipNameNr_QChart,
        {0, 0, 1},
        60, methods_QtCharts_QChart,
        15, enummembers_QtCharts_QChart,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtCharts_QChart,
    -1,
    -1,
    supers_QtCharts_QChart,
    SIP_NULLPTR,
    init_type_QtCharts_QChart,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QChart,
    SIP_NULLPTR,
    array_QtCharts_QChart,
    SIP_NULLPTR,
    release_QtCharts_QChart,
    cast_QtCharts_QChart,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtCharts_QChart,
    sizeof (::QtCharts::QChart),
};
